import { 
  select, 
  csv, 
  scaleLinear,
  scaleTime,
  extent, 
  axisLeft,
  axisBottom,
  area,
  curveBasis
  } from 'd3';

const svg = select('svg'); 

const width = +(svg.attr('width'));
const height = +(svg.attr('height'));

const render = data => { 
  const title = 'Basisn: Temperature in River';
  const xValue = d => d.timestamp;
  const xAxisLabel = d => 'Time';
  const yValue = d => d.temperature;
  const yAxisLabel = d => 'Temperature';
  const circleRadius = 10;
  const margin = {top: 55, right:50, bottom: 87, left: 150};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
        .domain(extent(data, xValue))
        .range([0, innerWidth]);
  
  const yScale = scaleLinear()
        .domain(extent(data, yValue))
        .range([innerHeight, 0])
        .nice();
  
  console.log(yScale.domain());
  
  const g = svg.append('g')
        .attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
        .ticks(5)
        .tickSize(-innerHeight)
        .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
        .tickSize(-innerWidth)
        .tickPadding(10);
  
        const yAxisG = g.append('g').call(yAxis);
              yAxisG.selectAll('.domain').remove();
      
  yAxisG.append('text')
             .attr('class', 'axis-label')
             .attr('y', -70)
             .attr('x', -innerHeight / 2)
             .attr('fill', 'black')
             .attr('transform', `rotate(-90)`)
             .attr('text-anchor', 'middle')
             .text(yAxisLabel);
   
  const xAxisG = g.append('g').call(xAxis) 
         .attr('transform', `translate(0, ${innerHeight})`);
  
          xAxisG.select('.domain').remove();
        
          xAxisG.append('text')
             .attr('class', 'axis-label')
             .attr('y', 75)
             .attr('x', innerWidth / 2)
             .attr('fill', 'black')
             .text(xAxisLabel);
  
   const areaGenerator = area() 
         .x(d => xScale(xValue(d)))
         .y0(innerHeight)
         .y1(d => yScale(yValue(d)))
         .curve(curveBasis);
  
  
    g.append('path')
          .attr('class', 'line-path')
          .attr('d', areaGenerator(data));
     
      g.append('text')
         .attr('class', 'title')
         .attr('y', -5)
         .text(title);
};

csv('https://vizhub.com/albanodossantos/datasets/temperature-river-basin.csv')
  .then(data => {
   data.forEach(d => {
    d.temperature = +d.temperature; 
    d.timestamp = new Date(d.timestamp) ;
   });
    render(data);
});